@@ -1,10 +1,10 @@
 /*
- * GL2PS, an OpenGL to Postscript Printing Library
- * Copyright (C) 1999-2001  Christophe Geuzaine
+ * GL2PS, an OpenGL to PostScript Printing Library
+ * Copyright (C) 1999-2002  Christophe Geuzaine
  *
- * $Id: gl2ps.h,v 1.8 2001/08/06 12:22:19 geuzaine Exp $
+ * $Id: gl2ps.h,v 1.27 2002/11/12 19:05:59 geuzaine Exp $
  *
- * E-mail: Christophe.Geuzaine@AdValvas.be
+ * E-mail: geuz@geuz.org
  * URL: http://www.geuz.org/gl2ps/
  *
  * This library is free software; you can redistribute it and/or
@@ -28,14 +28,41 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <GL/gl.h>
+#include <math.h>
 
-#define GL2PS_VERSION                    0.41
+/* To generate a Windows dll, you have to define GL2PSDLL at compile
+   time */
+
+#ifdef WIN32
+#include <windows.h>
+#ifdef GL2PSDLL
+#ifdef GL2PSDLL_EXPORTS
+#define GL2PSDLL_API __declspec(dllexport)
+#else
+#define GL2PSDLL_API __declspec(dllimport)
+#endif /* GL2PSDLL_EXPORTS */
+#else
+#define GL2PSDLL_API
+#endif /* GL2PSDLL */
+#else
+#define GL2PSDLL_API
+#endif /* WIN32 */
+
+#ifdef __APPLE__
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif /* __APPLE__ */
+
+
+#define GL2PS_VERSION                    0.63
 #define GL2PS_NONE                       0
 
 /* Output file format */
 
-#define GL2PS_EPS                        1
+#define GL2PS_PS                         1
+#define GL2PS_EPS                        2
+#define GL2PS_TEX                        3
 
 /* Sorting algorithms */
 
@@ -50,6 +77,9 @@
 #define GL2PS_SILENT                     (1<<2)
 #define GL2PS_BEST_ROOT                  (1<<3)
 #define GL2PS_OCCLUSION_CULL             (1<<4)
+#define GL2PS_NO_TEXT                    (1<<5)
+#define GL2PS_LANDSCAPE                  (1<<6)
+#define GL2PS_NO_PS3_SHADING             (1<<7)
 
 /* Arguments for gl2psEnable/gl2psDisable */
 
@@ -60,6 +90,11 @@
 /* Magic numbers */
 
 #define GL2PS_EPSILON                    5.e-3
+#define GL2PS_DEPTH_FACT                 1000.0
+#define GL2PS_SIMPLE_OFFSET              0.05
+#define GL2PS_SIMPLE_OFFSET_LARGE        1.0
+#define GL2PS_ZERO(arg)                  (fabs(arg)<1.e-20)
+/*#define GL2PS_ZERO(arg)                ((arg)==0.0)*/
 
 /* Message levels */
 
@@ -101,7 +136,6 @@
 
 typedef GLfloat GL2PSrgba[4];
 typedef GLfloat GL2PSxyz[3];
-typedef GLfloat GL2PSxy[2];
 typedef GLfloat GL2PSplane[4];
 
 typedef struct {
@@ -117,14 +151,6 @@ struct _GL2PSbsptree {
   GL2PSbsptree *front, *back;
 };
 
-typedef struct _GL2PSbsptree2d GL2PSbsptree2d;
-
-struct _GL2PSbsptree2d {
-  GLshort flag;
-  GL2PSxy a, b;
-  GL2PSbsptree2d *front, *back;
-};
-
 typedef struct {
   GL2PSxyz xyz;
   GL2PSrgba rgba;
@@ -136,18 +162,19 @@ typedef struct {
 } GL2PSstring;
 
 typedef struct {
-  GLshort type, numverts, boundary, dash, width;
-  GLfloat depth;
+  GLshort type, numverts, boundary, dash;
+  GLfloat width, depth;
   GL2PSvertex *verts;
   GL2PSstring *text;
 } GL2PSprimitive;
 
 typedef struct {
   GLint format, sort, options, colorsize, colormode, buffersize;
-  char *title, *producer;
+  char *title, *producer, *filename;
   GLboolean shade, boundary;
   GLfloat *feedback, offset[2];
-  GL2PSrgba *colormap;
+  GL2PSrgba *colormap, lastrgba, threshold;
+  float lastlinewidth;
   GL2PSlist *primitives;
   FILE *stream;
 } GL2PScontext;
@@ -155,14 +182,25 @@ typedef struct {
 
 /* public functions */
 
-GLvoid gl2psBeginPage(char *title, char *producer, GLint sort, GLint options, 
-		      GLint colormode, GLint colorsize, GL2PSrgba *colormap, 
-		      GLint buffersize, FILE * stream);
-GLint  gl2psEndPage(GLvoid);
-GLvoid gl2psText(char *str, char *fontname, GLint size);
-GLvoid gl2psEnable(GLint mode);
-GLvoid gl2psDisable(GLint mode);
-GLvoid gl2psPointSize(GLfloat value);
-GLvoid gl2psLineWidth(GLfloat value);
-
+#ifdef __cplusplus
+extern "C" {
 #endif
+
+GL2PSDLL_API void  gl2psBeginPage(char *title, char *producer, 
+				  GLint format, GLint sort, GLint options, 
+				  GLint colormode, GLint colorsize, 
+				  GL2PSrgba *colormap, GLint buffersize, 
+				  FILE *stream, char *filename);
+GL2PSDLL_API GLint gl2psEndPage(void);
+GL2PSDLL_API void  gl2psText(char *str, char *fontname, GLint size);
+GL2PSDLL_API void  gl2psEnable(GLint mode);
+GL2PSDLL_API void  gl2psDisable(GLint mode);
+GL2PSDLL_API void  gl2psPointSize(GLfloat value);
+GL2PSDLL_API void  gl2psLineWidth(GLfloat value);
+GL2PSDLL_API void  gl2psNumShadeColors(GLint nr, GLint ng, GLint nb);
+
+#ifdef __cplusplus
+};
+#endif
+
+#endif /* __GL2PS_H__ */
